@@ -14,6 +14,7 @@ except:
 import youtubeservice
 import cutetubewindows
 from cutetubeconfig import *
+from cutetubelog import CutetubeLog
 from videosharing import Twitter, Facebook
 from Ui_addtoplaylistdialog import Ui_AddToPlaylistDialog
 from Ui_newplaylistdialog import Ui_NewPlaylistDialog
@@ -21,7 +22,6 @@ from Ui_confirmdeletedialog import Ui_ConfirmDeleteDialog
 from Ui_addcommentdialog import Ui_AddCommentDialog
 from Ui_ratevideodialog import Ui_RateVideoDialog
 from Ui_searchdialog import Ui_searchDialog
-from Ui_aboutdialog import Ui_AboutDialog
 from Ui_switchaccountdialog import Ui_SwitchAccountDialog
 from Ui_manageaccountsdialog import Ui_ManageAccountsDialog
 from Ui_editaccountdialog import Ui_EditAccountDialog
@@ -707,57 +707,6 @@ class SettingsDialog(QDialog):
         QMaemo5InformationBox.information(self,  "Your settings have been saved")
         self.accept()
         
-class AboutDialog(QDialog, Ui_AboutDialog):
-    """
-    Class documentation goes here.
-    """
-    def __init__(self, parent = None):
-        """
-        Constructor
-        """
-        QDialog.__init__(self, parent)
-        self.setupUi(self)
-        self.connect(QApplication.desktop(), SIGNAL("resized(int)"), self.orientationChanged)
-        self.orientationChanged()
-        self.label.setPixmap(QPixmap(":/images/ui-images/cutetubehires.png"))
-        self.textEdit.viewport().setAutoFillBackground(False)
-        self.show()
-
-    def orientationChanged(self):
-        """
-        Re-orders the widgets when the application 
-        is in portrait mode.
-        """
-        screenGeometry = QApplication.desktop().screenGeometry()
-        if screenGeometry.height() > screenGeometry.width():
-            self.resize(480, 340)
-            self.label_3.setGeometry(QRect(10, 140, 371, 30))
-            self.websiteButton.setGeometry(QRect(10, 180, 460, 70))
-            self.donateButton.setGeometry(QRect(10, 260, 460, 70))
-            self.textEdit.setGeometry(QRect(130, 40, 360, 95))
-        else:   
-            self.resize(800, 190)
-            self.label_3.setGeometry(QRect(10, 155, 371, 30))
-            self.websiteButton.setGeometry(QRect(640, 30, 150, 70))
-            self.donateButton.setGeometry(QRect(640, 110, 150, 70))
-            self.textEdit.setGeometry(QRect(130, 40, 400, 100))            
-    
-    @pyqtSignature("")
-    def on_websiteButton_clicked(self):
-        """
-        Opens my webpage in the default browser.
-        """
-        os.system("dbus-send --system --type=method_call --dest=com.nokia.osso_browser /com/nokia/osso_browser/request com.nokia.osso_browser.load_url string:'http://marxianthecoder.blogspot.com'")
-        self.accept()
-    
-    @pyqtSignature("")
-    def on_donateButton_clicked(self):
-        """
-        Gimme your $$$$!
-        """
-        os.system("dbus-send --system --type=method_call --dest=com.nokia.osso_browser /com/nokia/osso_browser/request com.nokia.osso_browser.load_url string:'https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=stuhowarth77%40gmail%2ecom&lc=GB&item_name=cuteTube&currency_code=USD&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHosted'")
-        self.accept()
-
 class SwitchAccountDialog(QDialog, Ui_SwitchAccountDialog):
     """
     Dialog enabling the user to switch between accounts.
@@ -1131,13 +1080,16 @@ class TwitterAuthorisationDialog(QDialog):
             pincode = unicode(self.pinEdit.text(), "utf-8")
             self.toggleBusy(True)
             try:
+                CutetubeLog.logInfo("Attempting to authorise access to Twitter")
                 accessTokenKey, accessTokenSecret = Twitter.getAccessToken(pincode)
                 VideoSharingSettings.twitterAccessTokenKey = accessTokenKey
                 VideoSharingSettings.twitterAccessTokenSecret = accessTokenSecret
                 QMaemo5InformationBox.information(self, "cuteTube is now authorised to access your Twitter account")
                 VideoSharingSettings.raiseTwitterAuthorisationDialog = False
                 self.accept()
-            except:
+                CutetubeLog.logInfo("Authorised access to Twitter successfully")
+            except Exception, e:
+                CutetubeLog.logException("Unable to authorise access to Twitter: ")
                 QMaemo5InformationBox.information(self, "Unable to complete authorisation. Please check the pin code and try again")
             self.toggleBusy()
                 
@@ -1206,7 +1158,8 @@ class ShareViaTwitterDialog(QDialog):
                 Twitter.postMessage(message)
                 QMaemo5InformationBox.information(self, "Your message has been posted to Twitter")
                 self.accept()
-            except:
+            except Exception, e:
+                CutetubeLog.logException("Unable to post message to Twitter: ")
                 QMaemo5InformationBox.information(self, "Unable to post message to Twitter")
             self.toggleBusy()
             
@@ -1278,12 +1231,15 @@ class FacebookAuthorisationDialog(QDialog):
         self.toggleBusy(True)
         accessUrl = self.webView.url().toString()
         try:
+            CutetubeLog.logInfo("Attempting to authorise access to Facebook")
             accessToken = unicode(accessUrl, "utf-8").split("=")[1].split("&")[0] #Had to do this this because QUrl.queryItemValue() wouldn't work.
             VideoSharingSettings.facebookAccessToken = accessToken
             QMaemo5InformationBox.information(self, "cuteTube is now authorised to access your Facebook account")
             VideoSharingSettings.raiseFacebookAuthorisationDialog = False
             self.accept()
-        except:
+            CutetubeLog.logInfo("Authorised access to Facebook successfully")
+        except Exception, e:
+            CutetubeLog.logException("Unable to authorise access to Facebook: ")
             QMaemo5InformationBox.information(self, "Unable to confirm Facebook authorisation")
         self.toggleBusy()
             
@@ -1337,7 +1293,8 @@ class ShareViaFacebookDialog(QDialog):
                 Facebook.postMessage(message)
                 QMaemo5InformationBox.information(self, "Your message has been posted to Facebook")
                 self.accept()
-            except:
+            except Exception, e:
+                CutetubeLog.logException("Unable to post message to Facebook: ")
                 QMaemo5InformationBox.information(self, "Unable to post message to Facebook")
             self.toggleBusy()
         
