@@ -239,8 +239,9 @@ class CutetubeWindows(QMainWindow, Ui_CutetubeWindows):
                 self.pencilList.append(self.listWidget.row(item))
                 self.actionPencilQueue.setVisible(True)
                 self.actionPencilDownloads.setVisible(True)
-                self.actionPencilPlaylist.setVisible(True)
-                self.actionPencilFavourites.setVisible(True)
+                if youtubeservice.YouTubeDataService.currentUser != "":
+                    self.actionPencilPlaylist.setVisible(True)
+                    self.actionPencilFavourites.setVisible(True)
             else:
                 self.pencilList.remove(self.listWidget.row(item))
                 if len(self.pencilList) == 0:
@@ -436,8 +437,9 @@ class MostRecentWindow(CutetubeWindows):
         CutetubeWindows.__init__(self, parent)
         self.setWindowTitle("Most Recent")
         self.actionAddToQueue.setVisible(True)
-        self.actionAddToFavourites.setVisible(True)
-        self.actionAddToPlaylist.setVisible(True)
+        if youtubeservice.YouTubeDataService.currentUser != "":
+            self.actionAddToFavourites.setVisible(True)
+            self.actionAddToPlaylist.setVisible(True)
         self.actionPencil.setVisible(True)
         self.pencilList = []
         self.results = 0
@@ -461,8 +463,9 @@ class MostViewedWindow(CutetubeWindows):
         CutetubeWindows.__init__(self, parent)
         self.setWindowTitle("Today's Most Viewed")
         self.actionAddToQueue.setVisible(True)
-        self.actionAddToFavourites.setVisible(True)
-        self.actionAddToPlaylist.setVisible(True)
+        if youtubeservice.YouTubeDataService.currentUser != "":
+            self.actionAddToFavourites.setVisible(True)
+            self.actionAddToPlaylist.setVisible(True)
         self.actionPencil.setVisible(True)
         self.pencilList = []
         self.results = 0
@@ -486,8 +489,9 @@ class SearchResultsWindow(CutetubeWindows):
         CutetubeWindows.__init__(self, parent)
         self.setWindowTitle("Search Results")
         self.actionAddToQueue.setVisible(True)
-        self.actionAddToFavourites.setVisible(True)
-        self.actionAddToPlaylist.setVisible(True)
+        if youtubeservice.YouTubeDataService.currentUser != "":
+            self.actionAddToFavourites.setVisible(True)
+            self.actionAddToPlaylist.setVisible(True)
         self.actionPencil.setVisible(True)
         self.searchString = searchString
         self.pencilList = []
@@ -592,8 +596,9 @@ class UserWindow(CutetubeWindows):
         self.actionSearch.setVisible(True)
         self.actionSearch.setText("Search user's videos")
         self.actionAddToQueue.setVisible(True)
-        self.actionAddToFavourites.setVisible(True)
-        self.actionAddToPlaylist.setVisible(True)
+        if youtubeservice.YouTubeDataService.currentUser != "":
+            self.actionAddToFavourites.setVisible(True)
+            self.actionAddToPlaylist.setVisible(True)
         self.actionPencil.setVisible(True)
         self.pencilList = []
         self.results = 0
@@ -623,8 +628,9 @@ class RelatedVideosWindow(CutetubeWindows):
         CutetubeWindows.__init__(self, parent)
         self.setWindowTitle("Related Videos")
         self.actionAddToQueue.setVisible(True)
-        self.actionAddToFavourites.setVisible(True)
-        self.actionAddToPlaylist.setVisible(True)
+        if youtubeservice.YouTubeDataService.currentUser != "":
+            self.actionAddToFavourites.setVisible(True)
+            self.actionAddToPlaylist.setVisible(True)
         self.actionPencil.setVisible(True)
         self.video = video
         self.pencilList = []
@@ -920,9 +926,10 @@ class PlaybackQueueWindow(CutetubeWindows):
         self.setWindowTitle("My Playback Queue")
         self.actionPlayQueue.setVisible(True)
         self.actionClearQueue.setVisible(True)
-        self.actionSaveQueue.setVisible(True)
-        self.actionAddToFavourites.setVisible(True)
-        self.actionAddToPlaylist.setVisible(True)
+        if youtubeservice.YouTubeDataService.currentUser != "":
+            self.actionSaveQueue.setVisible(True)
+            self.actionAddToFavourites.setVisible(True)
+            self.actionAddToPlaylist.setVisible(True)
         self.actionRemoveFromQueue.setVisible(True)
         self.actionGoToQueue.setVisible(False)
         self.connect(self.actionRemoveFromQueue, SIGNAL("triggered()"), self.removeFromQueue)
@@ -1407,7 +1414,8 @@ class CommentsWindow(CutetubeWindows):
         """
         CutetubeWindows.__init__(self, parent)
         self.setWindowTitle("Comments")
-        self.actionAddComment.setVisible(True)
+        if youtubeservice.YouTubeDataService.currentUser != "":
+            self.actionAddComment.setVisible(True)
         self.actionGoToQueue.setVisible(False)
         self.show()
         self.video = video
